@@ -1,4 +1,4 @@
-qmboots <- function(dataset, nfactors, nsteps, load="auto", rotation="varimax", indet="qindtest", fsi=TRUE, forced=T, distribution=NULL, ...) {
+qmboots <- function(dataset, nfactors, nsteps, load="auto", rotation="varimax", indet="qindtest", fsi=TRUE, forced=T, distribution=NULL, cor.method="pearson", ...) {
   startime <- Sys.time()
   nstat <- nrow(dataset)
   nqsorts <- ncol(dataset)
@@ -56,7 +56,7 @@ qmboots <- function(dataset, nfactors, nsteps, load="auto", rotation="varimax",
     } else stop("Q method input: The factor loading matrix provided in 'load' should have the correct number of Q-sort as rows and the correct number of rotated factors as columns.")
   } else if (is.character(load) & length(load) == 1) {
     if (load == "auto") {
-      qm <- qmethod(dataset, nfactors, rotation=rotation, forced=forced, distribution=distribution, ...)
+      qm <- qmethod(dataset, nfactors, rotation=rotation, forced=forced, distribution=distribution, method=cor.method, ...)
       flagged <- qm$flagged
       target <- as.matrix(qm$loa)
       colnames(target) <- paste0("target_f", 1:nfactors)
@@ -85,7 +85,7 @@ qmboots <- function(dataset, nfactors, nsteps, load="auto", rotation="varimax",
                        indet, nfactors, nqsorts, nstat, 
                        qmts=qmts, qmts_log=qmts_log, 
                        flagged=flagged, forced=forced, 
-                       distribution=distribution, ...)
+                       distribution=distribution, method=cor.method, ...)
     # Export essential results: flagged, zsc and loa
     for (n in 1:nfactors) {
       # z-scores
